@@ -33,6 +33,7 @@
 ## 2024-03-19 rlnormCV
 ## 2024-07-31 addzeroCH tweaked to allow zero-row covariate df + drop = FALSE
 ## 2024-09-25 purged a couple of unused fn, moved xy2CH to xy2CH.R
+## 2024-10-09 span()
 ################################################################################
 
 # Global variables in namespace
@@ -42,7 +43,7 @@
 
 .localstuff <- new.env()
 
-##.localstuff$packageType <- ' pre-release'
+## .localstuff$packageType <- ' pre-release'
 .localstuff$packageType <- ''
 
 .localstuff$validdetectors <- c('single','multi','proximity','count', 
@@ -108,7 +109,7 @@ detectionfunctionnumber <- function (detname) {
 #-------------------------------------------------------------------------------
 
 parnames <- function (detectfn) {
-    parnames <- switch (detectfn+1,
+    switch (detectfn+1,
         c('g0','sigma'),   ## 0
         c('g0','sigma','z'),
         c('g0','sigma'),
@@ -578,10 +579,10 @@ add.cl <- function (df, alpha, loginterval, lowerbound = 0) {
 
 #-------------------------------------------------------------------------------
 
-spatialscale <- function (object, detectfn, session = '') {
+spatialscale <- function (object, detectfn, sessnum = 1) {
     if (inherits(object, 'secr')) {
         if (ms(object))
-            detpar <- detectpar(object)[[session]]
+            detpar <- detectpar(object)[[sessnum]]
         else
             detpar <- detectpar(object)
         cutval <- object$details$cutval
@@ -590,6 +591,7 @@ spatialscale <- function (object, detectfn, session = '') {
         detpar <- object
         cutval <- object$cutval
     }
+    
     if (!is.null(detpar$sigma)) detpar$sigma
     else if (detectfn == 10) {
         (cutval - detpar$beta0) / detpar$beta1
@@ -2025,3 +2027,21 @@ im2mask <- function(im) {
     read.mask(data = df, spacing = im$xstep)
 }
 #-------------------------------------------------------------------------------
+
+span <- function (object, ...) {
+    if (ms(object)) {
+        sapply(object, span, ...)
+    }
+    else {
+        if (is.null(object) || !('x' %in% names(object) && 'y' %in% names(object))) {
+            NULL
+        }
+        else {
+            rx <- range(object$x)
+            ry <- range(object$y)
+            max(diff(rx), diff(ry))
+        }
+    }
+}
+#-------------------------------------------------------------------------------
+
