@@ -68,7 +68,6 @@ List trappingsingle (
   std::vector<double> miscparm(4);
 
   // MAIN LINE 
-  RNGScope scope;             // Rcpp initialise and finalise random seed 
   for (i=0; i<N; i++) {
     caught[i] = 0;   // has animal i been caught in session? 
   }
@@ -193,7 +192,6 @@ List trappingmulti (
   
   cump[0] = 0;
   nc = 0;
-  RNGScope scope;             // Rcpp initialise and finalise random seed 
   for (s=0; s<ss; s++) {
     for (i=0; i<N; i++) {
       hsum(i) = 0;
@@ -286,7 +284,6 @@ List trappingcapped (
   std::vector<double> miscparm(4);
   double Tski;
   
-  RNGScope scope;             // Rcpp initialise and finalise random seed 
   cumh[0] = 0;
   for (s=0; s<ss; s++) {
     for (k=0; k<kk; k++) {
@@ -365,7 +362,6 @@ List trappingproximity (
   std::vector<int> caught(N);       // caught in session 
   std::vector<int> value(kk*ss*N);  // return value array of trap locations n x s x k
   
-  RNGScope scope;             // Rcpp initialise and finalise random seed 
   for (s=0; s<ss; s++) {
     for (i=0; i<N; i++) {
       for (k=0; k<kk; k++) {
@@ -433,7 +429,6 @@ List trappingcount (
   std::vector<double> miscparm(4);
   double Tski;
   
-  RNGScope scope;             // Rcpp initialise and finalise random seed 
   for (s=0; s<ss; s++) {
     for (i=0; i<N; i++) {
       for (k=0; k<kk; k++) {
@@ -521,7 +516,6 @@ List trappingpolygon (
   double dx,dy,d;
   double Tski = 1.0;
   
-  RNGScope scope;             // Rcpp initialise and finalise random seed 
   if (npoly>maxnpoly) {
     return (List::create(Named("resultcode") = 2, 
                          Named("n") = nc, 
@@ -653,7 +647,6 @@ List trappingtransect (
   rpoint xy;
   rpoint animal;
   NumericVector gsb(3); 
-  NumericMatrix gsbval(1,3); 
   double lx;
   double maxg = 0;
   double lambdak;
@@ -664,7 +657,6 @@ List trappingtransect (
   double H;
   double Tski;
   
-  RNGScope scope;             // Rcpp initialise and finalise random seed 
   cumk[0] = 0;
   for (k =0; k<ntransect; k++) {
     cumk[k+1] = cumk[k] + kk[k];
@@ -697,8 +689,7 @@ List trappingtransect (
         animal.x = animals(i,0);
         animal.y = animals(i,1);
         for (k=0; k<ntransect; k++) {         // each transect 
-          // if (used[s * ntransect + k]) {  
-          Tski = Tsk[s * ntransect + k];
+          Tski = Tsk(s,k);
           if (fabs(Tski) > 1e-10) {          // 2012 12 18 
             
             n1 = cumk[k];
@@ -706,19 +697,11 @@ List trappingtransect (
             gsb(0) = lambda[s];
             gsb(1) = sigma[s];
             gsb(2) = z[s];
-            H = hintegral1Ncpp(fn, as<std::vector<double>>(gsb)) / gsb(0);
+            H = hintegral1Dcpp(fn, gsb) / gsb(0);
             
-            // flaw in following: integral1D can exceed diameter 
-            gsbval(0,0) = gsb(0);
-            gsbval(0,1) = gsb(1);
-            gsbval(0,2) = gsb(2);
+            // flaw in following: integral1Dcpp can exceed diameter 
+            lambdak = gsb(0) * integral1Dcpp (fn, i, 0, gsb, 1, traps, animals, n1, n2, sumk, N) / H;
             
-            // conversions for RMatrix input to integralxDNRcpp
-            const RcppParallel::RMatrix<double> gsbvalR(gsbval);
-            const RcppParallel::RMatrix<double> trapsR(traps);
-            const RcppParallel::RMatrix<double> animalsR(animals);
-            
-            lambdak = gsb(0) * integral1DNRcpp (fn, i, 0, gsbvalR, trapsR, animalsR, n1, n2) / H;
             count = rcount(binomN[s], lambdak, Tski);
             maxg = 0;
             if (count>0) {    // find maximum - approximate 
@@ -851,7 +834,6 @@ List trappingpolygonX (
   int maybecaught;
   double Tski;
   
-  RNGScope scope;             // Rcpp initialise and finalise random seed 
   cumk[0] = 0;
   for (k =0; k<npoly; k++) cumk[k+1] = cumk[k] + kk[k];
   workXY = (double*) R_alloc(N*ss*2, sizeof(double));
@@ -977,7 +959,6 @@ List trappingtransectX (
   rpoint xy;
   rpoint animal;
   NumericVector gsb(3);
-  NumericMatrix gsbval(1,3);
   double lx;
   double maxg = 0;
   double lambdak;
@@ -991,7 +972,6 @@ List trappingtransectX (
   double pks;
   double Tski;
   
-  RNGScope scope;             // Rcpp initialise and finalise random seed 
   cumk = (int *) R_alloc(ntransect+1, sizeof(int));
   cumk[0] = 0;
   for (k =0; k<ntransect; k++)
@@ -1025,15 +1005,7 @@ List trappingtransectX (
       gsb(0) = lambda[s];
       gsb(1) = sigma[s];
       gsb(2) = z[s];
-      H = hintegral1Ncpp(fn, as<std::vector<double>>(gsb));
-      gsbval(0,0) = gsb(0);
-      gsbval(0,1) = gsb(1);
-      gsbval(0,2) = gsb(2);
-      
-      // conversions for RMatrix input to integralxDNRcpp
-      const RcppParallel::RMatrix<double> gsbvalR(gsbval);
-      const RcppParallel::RMatrix<double> trapsR(traps);
-      const RcppParallel::RMatrix<double> animalsR(animals);
+      H = hintegral1Dcpp(fn, gsb);
       
       for (i=0; i<N; i++) {                        // each animal 
         animal.x = animals(i,0);
@@ -1047,8 +1019,9 @@ List trappingtransectX (
             n1 = cumk[k];
             n2 = cumk[k+1]-1;
             
-            sumhaz += -log(1 - gsb(0) * integral1DNRcpp (fn, i, 0, gsbvalR, trapsR, 
-                                                    animalsR, n1, n2) / H);
+            sumhaz += -log(1 - gsb(0) * integral1Dcpp (fn, i, 0, gsb, 1, traps,
+                                                    animals, n1, n2, sumk, N) / H);
+            
           }
         }
         
@@ -1058,8 +1031,8 @@ List trappingtransectX (
           if (fabs(Tski) > 1e-10) {          // 2012 12 18 
             n1 = cumk[k];
             n2 = cumk[k+1]-1;
-            lambdak = gsb(0) * integral1DNRcpp (fn, i, 0, gsbvalR, trapsR, 
-                                           animalsR, n1, n2) / H;
+            lambdak = gsb(0) * integral1Dcpp (fn, i, 0, gsb, 1, traps,
+                                           animals, n1, n2, sumk, N) / H;
             pks = (1 - exp(-sumhaz)) * (-log(1-lambdak)) / sumhaz;
             count = unif_rand() < pks;
             maxg = 0;
@@ -1169,7 +1142,6 @@ List trappingsignal (
   NumericMatrix animalss = animals;
   double Tski;
   
-  RNGScope scope;             // Rcpp initialise and finalise random seed 
   worksignal = (double*) R_alloc(maxdet, sizeof(double));
   worknoise = (double*) R_alloc(maxdet, sizeof(double));
   sortorder = (int*) R_alloc(maxdet, sizeof(int));
@@ -1301,7 +1273,6 @@ List trappingtelemetry (
   double *sortkey;
   double Tski = 1.0;   // not defined !! 2012-12-18 
   
-  RNGScope scope;             // Rcpp initialise and finalise random seed 
   workXY = (double*) R_alloc(maxdet*2, sizeof(double));
   sortorder = (int*) R_alloc(maxdet, sizeof(int));
   sortkey = (double*) R_alloc(maxdet, sizeof(double));
